disp('---------------------------------------------------');
disp('       Matlab sript for plotting TFEM misfit       ');
% Plots time-frequency TFEM misfit

clear all;
cmap=load('jet_modn');         % colorscale

fid=fopen('MISFITS.DAT');
MISFITS=fscanf(fid,'%g',inf);
fmin=log10( MISFITS(1) );
fmax=log10( MISFITS(2) );
NFREQ= MISFITS(3);
N= MISFITS(4);
dt= MISFITS(5);
fclose(fid);

df=(fmax-fmin)/(NFREQ-1);                                         

xmin=0.;       % beginning time (time for the first sample in data)
xmax=dt*(N-1); % ending time
ymin=fmin;     % lower frequency limit
ymax=fmax;     % upper frequency limit

% Time Tics
dx=[xmin:1:xmax];                         
dxLabel={[xmin:1:xmax]};
% Frequency Ticks
y_lin=cat(2,[0.1:0.1:0.9],[1:1:9],[10:10:50]);
dyLabel={'0.1';'';'';'';'';'';'';'';'';'1';'';'';'';'';'';'';'';'';'10';'';'';'';'50';};
dy=log10(y_lin);            % recalculating to log scale

for i=1:1:NFREQ;		    % frequency vector for plotting in TF plane
  freq(i)=ymin+(i-1)*df;
end
for i=1:1:N;                % time vector for plotting in TF plane
  time(i)=xmin+dt*(i-1);	
end

fid=fopen('TFEM.DAT');      % reading from file with TFEM results
for i=1:1:NFREQ;
  a=fscanf(fid,'%g',[1 N]); 
  tfa(i,:)=a;                
end
fclose(fid);

tfamax=max(max(tfa));  
col_max= tfamax;

figure;
[C,h,cf]=contourf(time,freq,tfa,[-col_max:col_max/20:col_max]);
set(h,'EdgeColor','none', 'FaceColor', 'flat');
colormap(cmap); 
caxis([-col_max col_max]);  % setting limits for colorbar
set(gca,'XTick',[dx]);
set(gca,'XTickLabel',dxLabel);
set(gca,'TickDir','out');
set(gca,'YTick',[dy]);
set(gca,'YTickLabel',dyLabel);

xlim([xmin xmax]);          % setting limits for axes
ylim([ymin ymax]); 
set(gca,'FontSize',8);

colorbar;

% save figure to TIFF file, resolution 300 dpi 
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperPosition', [0.25 2.5 8.0 8.0]);  
print('-f','-dtiff','-r300','Misf_TFEM.tiff')
